import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable, Subscribable } from 'rxjs';
import { SettingsDTO } from 'src/app/models/config/settings.dto';
import { SoftwareVersionDTO } from 'src/app/models/config/software-version.dto';
import { SettingsService } from '../settings/settings.service';

@Injectable({
  providedIn: 'root'
})
export class GuiService {

  constructor(
    private appsettings: SettingsService,
    private http: HttpClient,
  ) { }

  getApiVersion(): Observable<SoftwareVersionDTO> {
    return this.http.get<SoftwareVersionDTO>(`${this.appsettings.getApiURL()}/api/gui/api-version`, {
      headers: new HttpHeaders({
        'Content-Type': 'application/json'
      })
    });
  }

  getSettings(): Observable<SettingsDTO> {
    return this.http.get<SettingsDTO>(`${this.appsettings.getApiURL()}/api/gui/settings`, {
      headers: new HttpHeaders({
        'Content-Type': 'application/json'
      })
    });
  }

  sendTestMail(mail: string): Observable<unknown> {
    return this.http.post(`${this.appsettings.getApiURL()}/api/gui/send-test-mail/${mail}`, {
      headers: new HttpHeaders({
        'Content-Type': 'application/json'
      })
    });
  }
}
