import { Injectable } from "@angular/core";
import { ToastOptions } from "src/app/models/utils/toast-options";
import { SettingsService } from "../settings/settings.service";
import { SpinnerService } from "../spinner/spinner.service";
import { ToastService } from "../toast/toast.service";
import io from "socket.io-client";
import { MessageService } from "primeng/api";

@Injectable({
  providedIn: "root"
})
export class SocketService {
  private socket: any;
  disconnected = false;

  constructor(
    private settingsService: SettingsService,
    private toastService: ToastService,
    private spinnerService: SpinnerService,
    private messageService: MessageService
  ) {
  }

  startSocket() {
    this.socket = io(`${this.settingsService.getApiURL()}`, { path: "/api/socket.io" });
    this.socket.on("connect", () => {
      if (this.disconnected) {
        this.spinnerService.hideSpinner();
        const options: ToastOptions = {
          closable: false
        };
        this.messageService.clear();
        this.toastService.info("Server verbunden", "Die Verbindung zum Server konnte hergestellt werden.", options);
      }

      this.disconnected = false;
      console.info("Connected!");
    });

    this.socket.on("connect_error", (err: Error) => {
      if (this.disconnected) {
        this.spinnerService.showSpinner();
        return;
      }

      console.warn("Connect error!");
      this.disconnected = true;
      const options: ToastOptions = {
        sticky: true,
        closable: false
      };
      this.messageService.clear();
      this.toastService.error("Server nicht erreichbar", "Die Verbindung zum Server konnte nicht hergestellt werden!\nLaden Sie die Seite neu.", options);
      console.error(err.toString());
    });

    this.socket.on("disconnect", () => {
      if (this.disconnected) {
        this.spinnerService.showSpinner();
        return;
      }

      console.warn("Disconnected!");
      this.disconnected = true;
      const options: ToastOptions = {
        sticky: true,
        closable: false
      };
      this.spinnerService.showSpinner();
      this.messageService.clear();
      this.toastService.error("Verbindung unterbrochen", "Die Verbindung zum Server konnte nicht hergestellt werden!\nLaden Sie die Seite neu.", options);
    });
  }
}
